# API Autodocs #

## The LazyImporter Class ##

```{eval-rst}
.. autoclass:: ducktools.lazyimporter::LazyImporter
```

## Importers ##

```{eval-rst}
.. autoclass:: ducktools.lazyimporter::ModuleImport
.. autoclass:: ducktools.lazyimporter::FromImport
.. autoclass:: ducktools.lazyimporter::MultiFromImport
.. autoclass:: ducktools.lazyimporter::TryExceptImport
.. autoclass:: ducktools.lazyimporter::TryExceptFromImport
```

## Functions ##

```{eval-rst}
.. autofunction:: ducktools.lazyimporter::get_importer_state
.. autofunction:: ducktools.lazyimporter::get_module_funcs
.. autofunction:: ducktools.lazyimporter::force_imports
```
